==> tine20-allinone_2019.12.5.tar.bz2: Setup/js/Setup-lang-ru-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Russian (http://www.transifex.com/tine20/tine20/language/ru/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: ru\nPlural-Forms: nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Backend"
: "Бэкенд"

, "Standard IMAP"
: "Стандартный IMAP"

, "Standard SMTP"
: "Стандартный SMTP"

, "Imap"
: "Imap"

, "Hostname"
: "Имя узла"

, "Username"
: "Имя пользователя"

, "Password"
: "Пароль"

, "Port"
: "Порт"

, "Secure Connection"
: "Безопасное подключение"

, "None"
: "Нет"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Verify peer Certificate"
: ""

, "Use system account"
: "Использование системной учетной записи"

, "No"
: "Нет"

, "Yes"
: "Да"

, "Append domain to login name"
: "Добавить имя домена в логин"

, "Use email address as login name"
: ""

, "Cyrus Admin"
: ""

, "Cyrus Admin Password"
: ""

, "Use proxy auth"
: ""

, "Smtp"
: "Smtp"

, "Authentication"
: "Аутентификация"

, "Login"
: "Имя пользователя"

, "Plain"
: "Обычная"

, "Primary Domain"
: "Основной домен"

, "Secondary Domains (comma separated)"
: ""

, "Notifications service address"
: "Адрес службы уведомлений"

, "Notification Username"
: "Имя службы уведомлений"

, "Notification Password"
: "Пароль службы уведомлений"

, "Notifications local client (hostname or IP address)"
: ""

, "SIEVE"
: "SIEVE"

, "MySql Hostname"
: "Хост MySQL"

, "MySql Database"
: "База данных MySql"

, "MySql User"
: "Пользователь MySql"

, "MySql Password"
: "Пароль MySql"

, "MySql Port"
: "Порт MySql"

, "User or UID"
: "Пользователь или UID"

, "Group or GID"
: "Группа или GID"

, "Home Template"
: ""

, "Password Scheme"
: "Схема пароля"

, "PLAIN-MD5"
: "PLAIN-MD5"

, "MD5-CRYPT"
: "MD5-CRYPT"

, "SHA1"
: "SHA1"

, "SHA256"
: "SHA256"

, "SSHA256"
: "SSHA256"

, "SHA512"
: "SHA512"

, "SSHA512"
: "SSHA512"

, "PLAIN"
: "PLAIN"

, "I have read the license agreement and accept it"
: "Я прочитал лицензионное соглашение и согласен его соблюдать"

, "License Agreement"
: "Лицензионное соглашение"

, "I have read the privacy agreement and accept it"
: "Я прочёл соглашение о приватных данных и согласен с ними"

, "Privacy Agreement"
: "Соглашение о приватных данных"

, "Accept Terms and Conditions"
: "Согласен с правилами и условиями"

, "Performing Environment Checks..."
: "Проведение проверок окружения..."

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: ""

, "Check"
: "Проверка"

, "Result"
: "Результат"

, "Error"
: "Ошибка"

, "Run setup tests"
: "Запуск тестов установки"

, "Ignore setup tests"
: "Пропустить тестирование"

, "Install application"
: "Установить приложение"

, "File"
: "Файл"

, "Setup Authentication"
: "Аутентификация установки"

, "Database"
: "База данных"

, "User"
: "Пользователь"

, "Prefix"
: "Префикс"

, "Logging"
: "Регистрация"

, "Filename"
: "Имя файла"

, "Priority"
: "Приоритет"

, "Caching"
: "Кэширование"

, "Lifetime (seconds)"
: "Время жизни (секунд)"

, "Path"
: "Путь"

, "Queue"
: "Очередь"

, "Session"
: "Сессия"

, "Temporary files"
: "Временные файлы"

, "Temporary Files Path"
: "Путь к временным файлам"

, "Filestore directory"
: "Каталог хранилища файлов"

, "Filestore Path"
: ""

, "Addressbook Map panel"
: ""

, "Map panel"
: "Карта"

, "disabled"
: "отключен"

, "enabled"
: "включен"

, "Config file is not writable"
: "Config файл защищен от записи"

, "Save config"
: "Сохранить конфигурацию"

, "Download config file"
: "Загрузить файл конфигурации"

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Terms and Conditions"
: "Условия и Положения"

, "Setup Checks"
: "Проверки установки"

, "Config Manager"
: "Управление конфигурацией"

, "Authentication/Accounts"
: ""

, "Email"
: "Электронная почта"

, "Application Manager"
: "Управление приложениями"

, "Delete all existing users and groups"
: "Удалить всех существующих пользователей и группы"

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: "Переключение с SQL на LDAP удалит все учётные записи, группы и роли. Вы действительно хотите переключить хранилище учётных записей на LDAP?"

, "TLS client certificate"
: "TLS сертификат клиента"

, "Initial Admin User"
: "Первоначальный администратор"

, "Initial admin login name"
: "имя первоначального администратора"

, "Initial admin Password"
: "пароль первоначального администратора"

, "Password confirmation"
: "Подтверждение пароля"

, "Authentication provider"
: "Проверка подлинности поставщика"

, "Try to split username"
: "Попробуйте разделить имя пользователя"

, "Account canonical form"
: ""

, "Account domain name"
: "Название Домена"

, "Account domain short name"
: ""

, "Host"
: "Хост"

, "Login name"
: "Имя"

, "Bind requires DN"
: ""

, "Start TLS"
: ""

, "Base DN"
: ""

, "Search filter"
: "Фильтр поиска"

, "Certificate validation"
: "Проверка сертификата"

, "CA file"
: "CA файл"

, "CRL directory"
: "CRL директория"

, "Accounts storage"
: "Хранилище учётных записей"

, "Default user group name"
: "Группа пользователей по-умолчанию"

, "Default admin group name"
: "Группа администраторов по-умолчанию"

, "Login panel"
: "Авторизация"

, "Reuse last username logged"
: ""

, "Password Settings"
: "Настройки пароля"

, "User can change password"
: "Пользователь должен сменить пароль"

, "Enable password policy"
: "Включить политику паролей"

, "Only ASCII"
: "Только ASCII"

, "Minimum length"
: "Минимальная длина"

, "Minimum word chars"
: "Минимум символов"

, "Minimum uppercase chars"
: "Минимум прописных букв"

, "Minimum special chars"
: "Минимум спецсимволов"

, "Minimum numbers"
: "Минимум цифр"

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: ""

, "Redirect Settings"
: "Перенаравление настройка"

, "Redirect Url (redirect to login screen if empty)"
: ""

, "Redirect Always (if No, only redirect after logout)"
: ""

, "Redirect to referring site, if exists"
: ""

, "Password encoding"
: "Кодирование паролей"

, "des"
: "des"

, "crypt"
: ""

, "blowfish_crypt"
: "blowfish_crypt"

, "md5_crypt"
: "md5_crypt"

, "ext_crypt"
: "ext_crypt"

, "md5"
: "md5"

, "smd5"
: "smd5"

, "sha"
: "sha"

, "ssha"
: "ssha"

, "ntpassword"
: "ntpassword"

, "plain"
: "простой"

, "User DN"
: ""

, "User Filter"
: "Фильтр пользователей"

, "User Search Scope"
: "Область поиска для пользователей"

, "Groups DN"
: "DN групп"

, "Group Filter"
: "Фильтр группы"

, "Group Search Scope"
: "Область поиска для группы"

, "Use Rfc 2307 bis"
: "Использовать Rfc 2307 bis"

, "Maintain RFC 2307 attributes"
: ""

, "Min User Id"
: "Мин ID пользователя"

, "Max User Id"
: "Макс ID пользователя"

, "Min Group Id"
: "Минимальный ID группы"

, "Max Group Id"
: "Максимальный ID группы"

, "Group UUID Attribute name"
: ""

, "User UUID Attribute name"
: ""

, "Readonly access"
: "Доступ только на чтение"

, "Save config and install"
: "Сохранить конфигурацию и установить"

, "Passwords don't match"
: "Пароли не совпадают"

, "Should not be empty"
: "Не должен быть пустым"

, "Setup"
: ""

, "Application, Applications"
: [
  "Приложение"
 ,"Приложения"
 ,"Приложений"
 ,"Приложений"

]
, "Name"
: "Имя"

, "Enabled"
: "Позволенный"

, "Order"
: "Последовательность"

, "Installed Version"
: "Установленная версия"

, "Available Version"
: "Доступная версия"

, "Status"
: "Статус"

, "Depends on"
: "Зависит от"

, "Uninstall application"
: "Удалить приложение"

, "Update application"
: "Обновить приложение"

, "Go to {0} login"
: "Залогиниться в {0}"

, "uninstall"
: "удалить"

, "Do you really want to uninstall the application(s)?"
: "Вы действительно хотите удалить приложение(я)?"

, "This may take a while"
: "Это может занять некоторое время"

, "Dependency Violation"
: "Нарушена зависимость"

, "CLI Required"
: ""

, "Application"
: "Приложение"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.03.4.tar.bz2: Setup/js/Setup-lang-ru-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Russian (http://www.transifex.com/tine20/tine20/language/ru/)\nLanguage: ru\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "I have read the license agreement and accept it"
: "Я прочитал лицензионное соглашение и согласен его соблюдать"

, "License Agreement"
: "Лицензионное соглашение"

, "I have read the privacy agreement and accept it"
: "Я прочёл соглашение о приватных данных и согласен с ними"

, "Privacy Agreement"
: "Соглашение о приватных данных"

, "Accept Terms and Conditions"
: "Согласен с правилами и условиями"

, "Backend"
: "Бэкенд"

, "Standard IMAP"
: "Стандартный IMAP"

, "Standard SMTP"
: "Стандартный SMTP"

, "Imap"
: "Imap"

, "Hostname"
: "Имя узла"

, "Username"
: "Имя пользователя"

, "Password"
: "Пароль"

, "Port"
: "Порт"

, "Secure Connection"
: "Безопасное подключение"

, "None"
: "Нет"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Verify peer Certificate"
: ""

, "Use system account"
: "Использование системной учетной записи"

, "No"
: "Нет"

, "Yes"
: "Да"

, "Append domain to login name"
: "Добавить имя домена в логин"

, "Use email address as login name"
: ""

, "Cyrus Admin"
: ""

, "Cyrus Admin Password"
: ""

, "Use proxy auth"
: ""

, "Smtp"
: "Smtp"

, "Authentication"
: "Аутентификация"

, "Login"
: "Имя пользователя"

, "Plain"
: "Обычная"

, "Primary Domain"
: "Основной домен"

, "Secondary Domains (comma separated)"
: ""

, "Notifications service address"
: "Адрес службы уведомлений"

, "Notification Username"
: "Имя службы уведомлений"

, "Notification Password"
: "Пароль службы уведомлений"

, "Notifications local client (hostname or IP address)"
: ""

, "SIEVE"
: "SIEVE"

, "MySql Hostname"
: "Хост MySQL"

, "MySql Database"
: "База данных MySql"

, "MySql User"
: "Пользователь MySql"

, "MySql Password"
: "Пароль MySql"

, "MySql Port"
: "Порт MySql"

, "User or UID"
: "Пользователь или UID"

, "Group or GID"
: "Группа или GID"

, "Home Template"
: ""

, "Password Scheme"
: "Схема пароля"

, "PLAIN-MD5"
: "PLAIN-MD5"

, "MD5-CRYPT"
: "MD5-CRYPT"

, "SHA1"
: "SHA1"

, "SHA256"
: "SHA256"

, "SSHA256"
: "SSHA256"

, "SHA512"
: "SHA512"

, "SSHA512"
: "SSHA512"

, "PLAIN"
: "PLAIN"

, "Terms and Conditions"
: "Условия и Положения"

, "Setup Checks"
: "Проверки установки"

, "Config Manager"
: "Управление конфигурацией"

, "Authentication/Accounts"
: ""

, "Email"
: "Электронная почта"

, "Application Manager"
: "Управление приложениями"

, "Setup"
: ""

, "Name"
: "Имя"

, "Enabled"
: "Позволенный"

, "Order"
: "Последовательность"

, "Installed Version"
: "Установленная версия"

, "Available Version"
: "Доступная версия"

, "Status"
: "Статус"

, "Depends on"
: "Зависит от"

, "Install application"
: "Установить приложение"

, "Uninstall application"
: "Удалить приложение"

, "Update application"
: "Обновить приложение"

, "Go to {0} login"
: "Залогиниться в {0}"

, "uninstall"
: "удалить"

, "Do you really want to uninstall the application(s)?"
: "Вы действительно хотите удалить приложение(я)?"

, "This may take a while"
: "Это может занять некоторое время"

, "Dependency Violation"
: "Нарушена зависимость"

, "CLI Required"
: ""

, "Delete all existing users and groups"
: "Удалить всех существующих пользователей и группы"

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: "Переключение с SQL на LDAP удалит все учётные записи, группы и роли. Вы действительно хотите переключить хранилище учётных записей на LDAP?"

, "TLS client certificate"
: "TLS сертификат клиента"

, "Initial Admin User"
: "Первоначальный администратор"

, "Initial admin login name"
: "имя первоначального администратора"

, "Initial admin Password"
: "пароль первоначального администратора"

, "Password confirmation"
: "Подтверждение пароля"

, "Authentication provider"
: "Проверка подлинности поставщика"

, "Try to split username"
: "Попробуйте разделить имя пользователя"

, "Account canonical form"
: ""

, "Account domain name"
: "Название Домена"

, "Account domain short name"
: ""

, "Host"
: "Хост"

, "Login name"
: "Имя"

, "Bind requires DN"
: ""

, "Start TLS"
: ""

, "Base DN"
: ""

, "Search filter"
: "Фильтр поиска"

, "Certificate validation"
: "Проверка сертификата"

, "CA file"
: "CA файл"

, "CRL directory"
: "CRL директория"

, "Accounts storage"
: "Хранилище учётных записей"

, "Default user group name"
: "Группа пользователей по-умолчанию"

, "Default admin group name"
: "Группа администраторов по-умолчанию"

, "Login panel"
: "Авторизация"

, "Reuse last username logged"
: ""

, "Password Settings"
: "Настройки пароля"

, "User can change password"
: "Пользователь должен сменить пароль"

, "Enable password policy"
: "Включить политику паролей"

, "Only ASCII"
: "Только ASCII"

, "Minimum length"
: "Минимальная длина"

, "Minimum word chars"
: "Минимум символов"

, "Minimum uppercase chars"
: "Минимум прописных букв"

, "Minimum special chars"
: "Минимум спецсимволов"

, "Minimum numbers"
: "Минимум цифр"

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: ""

, "Redirect Settings"
: "Перенаравление настройка"

, "Redirect Url (redirect to login screen if empty)"
: ""

, "Redirect Always (if No, only redirect after logout)"
: ""

, "Redirect to referring site, if exists"
: ""

, "Password encoding"
: "Кодирование паролей"

, "des"
: "des"

, "crypt"
: ""

, "blowfish_crypt"
: "blowfish_crypt"

, "md5_crypt"
: "md5_crypt"

, "ext_crypt"
: "ext_crypt"

, "md5"
: "md5"

, "smd5"
: "smd5"

, "sha"
: "sha"

, "ssha"
: "ssha"

, "ntpassword"
: "ntpassword"

, "plain"
: "простой"

, "User DN"
: ""

, "User Filter"
: "Фильтр пользователей"

, "User Search Scope"
: "Область поиска для пользователей"

, "Groups DN"
: "DN групп"

, "Group Filter"
: "Фильтр группы"

, "Group Search Scope"
: "Область поиска для группы"

, "Use Rfc 2307 bis"
: "Использовать Rfc 2307 bis"

, "Maintain RFC 2307 attributes"
: ""

, "Min User Id"
: "Мин ID пользователя"

, "Max User Id"
: "Макс ID пользователя"

, "Min Group Id"
: "Минимальный ID группы"

, "Max Group Id"
: "Максимальный ID группы"

, "Group UUID Attribute name"
: ""

, "User UUID Attribute name"
: ""

, "Readonly access"
: "Доступ только на чтение"

, "Save config and install"
: "Сохранить конфигурацию и установить"

, "Save config"
: "Сохранить конфигурацию"

, "Passwords don't match"
: "Пароли не совпадают"

, "Should not be empty"
: "Не должен быть пустым"

, "Performing Environment Checks..."
: "Проведение проверок окружения..."

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: ""

, "Check"
: "Проверка"

, "Result"
: "Результат"

, "Error"
: "Ошибка"

, "Run setup tests"
: "Запуск тестов установки"

, "Ignore setup tests"
: "Пропустить тестирование"

, "Application, Applications"
: [
  "Приложение"
 ,"Приложения"
 ,"Приложений"
 ,"Приложений"

]
, "File"
: "Файл"

, "Setup Authentication"
: "Аутентификация установки"

, "Database"
: "База данных"

, "User"
: "Пользователь"

, "Prefix"
: "Префикс"

, "Logging"
: "Регистрация"

, "Filename"
: "Имя файла"

, "Priority"
: "Приоритет"

, "Caching"
: "Кэширование"

, "Lifetime (seconds)"
: "Время жизни (секунд)"

, "Path"
: "Путь"

, "Queue"
: "Очередь"

, "Session"
: "Сессия"

, "Temporary files"
: "Временные файлы"

, "Temporary Files Path"
: "Путь к временным файлам"

, "Filestore directory"
: "Каталог хранилища файлов"

, "Filestore Path"
: ""

, "Addressbook Map panel"
: ""

, "Map panel"
: "Карта"

, "disabled"
: "отключен"

, "enabled"
: "включен"

, "Config file is not writable"
: "Config файл защищен от записи"

, "Download config file"
: "Загрузить файл конфигурации"

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Application"
: "Приложение"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
